make_search_path

Function make_search_path 

pub fn make_search_path(default_libexec_path: Option<&str>) -> Option<OsString>
Make an os-specific search path.

This concatenates SNIX_LIBEXEC_PATH environment variable, default_libexec_path argument, PATH environment variable and the directory of the current executable into one string separated by the os-specific path separator.

It does this to crate one giant search path of places to look for a sub-command binary.